@@ -48,12 +48,7 @@ sumSpectra <- function(spectra, ...){
 
 	if (!("tol" %in% args)) {
 		fdiff <- diff(spectra$freq)
-		ff <- 0.5 # Fudge factor
-		if (length(unique(fdiff)) == 1) tol <- abs(fdiff[1])*ff
-		if (length(unique(fdiff)) > 1) tol <- abs(min(fdiff))*ff
-# version prior to December 2016:
-#		if (length(unique(fdiff)) == 1) tol <- abs(fdiff[1]) + abs(0.01*fdiff[1])
-#		if (!length(unique(fdiff)) == 1) tol <- abs(min(fdiff)) + 0.01*abs(min(fdiff))
+		tol <- abs(mean(fdiff)) * 1.2
 		h <- check4Gaps(spectra$freq, tol = tol)	
 		}
 
